---

title: About Us
description: This is the page description
---


<div class="wrapper">
    <section class="container">
        <h3 class="title">{{ page.title }}</h3>
        <p>
            This is the about-us page
        </p>
        {{ page_link('index', text='Home') }}
    </section>
</div>
