---

title: Advanced Paged
description: This page mix and match some advanced concepts
data:
    title: Locations
    locations:
        - Charlotte
        - Concord
        - North Carolina
---


<div class="wrapper">
    <section class="container">
       
        <h3 class="title">{{ page.title }}</h3>
        <p> {{ page.description }} </p>
        <hr> 

        <h4>Page level data</h4>
        <h5>{{ page.data.title }}</h5>
        <ul>
            {% for loc in page.data.locations %}
            <li>{{ loc }}</li>
            {% endfor %}
        </ul>

        <hr>

        <h4>Data from <strong>data/cars.json</strong></h4>
        
        <ul>
            {% for car in data.cars.my_list %}
            <li>{{ car }}</li>
            {% endfor %}
        </ul>
        
        <hr>
        <h4>Include from content </h4>
        {% include 'content/my_table.html' %}
        <hr>

        {% include 'content/hello-world.md' %}

        {{ page_link('index', text='Home') }}
    </section>
</div>
