---
title: Welcome to my site
---

<template>

    <div class="wrapper">

        <header class="header">
            <div class="container">

                <h1 class="title">{{ site.__generator__.name }}</h1>
                <p class="description">An elegant static site generator that makes sense<br>
                    <i><small>Currently {{ site.__generator__.version }}</small></i>
                </p>
                <a class="button" target="_blank" href="https://github.com/mardix/mambo" title="Getting Started">Documentation</a>
        
            </div>
        </header>

        <section class="container">
            <h3 class="title">Simple and Elegant</h3>
            <p><strong>Mambo</strong> is an elegant static site generator built in Python. 
            It doesn't lock you in any framework way, instead it lets you have it your way. 
            Create pages in HTML or Markdown; write HTML, JS & CSS in a single file component; 
            build your pages; deploy to your host; Mambo keeps it simple and elegant!
            </p>

            <h4 class="title">Link examples</h4>
            
            {{ page_link('about') }} - 
            {{ page_link('contact') }} - 
            {{ page_link('advanced') }} - 
            {{ page_link('articles/last') }} - 
            {{ page_link('blog', title="Blog") }}

            <hr>
            
            <div>
              Environment: 
                {% if site.__env__ == "production" %} 
                    Production 
                {% elif site.__env__ == "dev" %}
                    Dev
                {% endif %}
            </div>

            static url test checksum: 
            <ul>
                <li>AS IS {{ static_url('main.css') }}</li>
                <li>WITH CHECKSUM {{ static_url('main.js') }}</li>
            </ul>
             
        </section>
    </div>
</template>

<script type="text/javascript">
    console.log('this is from index.html!');
</script>

<style>
.main-title {
    text-align: center
}
</style>







