

<div class="wrapper">
  <hr />
  <footer class="footer">
    <section class="container">
      &copy; {{ "now" | format_date('YYYY') }} {{ site.name }}
    </section>
  </footer>
</div>

{% for script in page.assets.scripts %}
  {{ script_tag(script.url, attributes=script.attributes) }}
{% endfor %}

</body>
</html>